import { Box, Text, useApp } from "ink";
import Link from "ink-link";
import SelectInput from "ink-select-input";
import Spinner from "ink-spinner";
import TextInput from "ink-text-input";
import React, { useReducer, useState } from "react";
import { recycleService } from "./api.js";
import { toFile } from "./ical.js";
import { reducer } from "./utils.js";
const isPostalCodeValid = (code) => code >= 1000 && code <= 9999;
export const formReducer = reducer();
export const optionReducer = reducer();
export default function App({ token = "" }) {
    const [activeStep, setActiveStep] = useState("ENTER_POSTAL_CODE");
    const [form, updateForm] = useReducer(formReducer, {});
    const [choice, updateChoice] = useReducer(formReducer, {});
    const [options, updateOptions] = useReducer(optionReducer, {
        postalCode: [],
        street: [],
        house: [],
    });
    const { exit } = useApp();
    const api = recycleService(token);
    return (React.createElement(Box, { flexDirection: "column", gap: 1 },
        React.createElement(Box, null,
            React.createElement(Box, { borderStyle: "doubleSingle" },
                React.createElement(Text, null, "Recycle \u27A1\uFE0F \uD83D\uDCC6"))),
        activeStep === "LOADING" && React.createElement(Spinner, null),
        activeStep === "ENTER_POSTAL_CODE" && (React.createElement(TextInput, { placeholder: "Postal code", value: form.postalCode ?? "", onChange: postalCode => {
                updateForm({ postalCode });
            }, onSubmit: async () => {
                if (form?.postalCode === undefined)
                    return;
                const code = Number.parseInt(form.postalCode, 10);
                if (!isPostalCodeValid(code))
                    return;
                setActiveStep("LOADING");
                const ids = await api.getPostalCodeId(code);
                if (ids.length === 0)
                    return;
                setActiveStep("SELECT_POSTAL_CODE");
                updateOptions({ postalCode: ids });
            } })),
        activeStep === "SELECT_POSTAL_CODE" && (React.createElement(SelectInput, { items: options.postalCode, onSelect: ({ value, label }) => {
                const postalCode = value.split("#")[0] ?? "";
                updateChoice({ postalCode });
                updateForm({ postalCode: label.split(" - ").join(" ") });
                setActiveStep("ENTER_STREET_NAME");
            } })),
        activeStep === "ENTER_STREET_NAME" && (React.createElement(TextInput, { placeholder: "Street", value: form.street ?? "", onChange: street => {
                updateForm({ street });
            }, onSubmit: async () => {
                if (form.street === undefined ||
                    choice.postalCode === undefined ||
                    form.street.length < 5) {
                    return;
                }
                setActiveStep("LOADING");
                const ids = await api.getStreetId(choice.postalCode, form.street);
                if (ids.length === 0) {
                    setActiveStep("ENTER_STREET_NAME");
                    return;
                }
                setActiveStep("SELECT_STREET_NAME");
                updateOptions({ street: ids });
            } })),
        activeStep === "SELECT_STREET_NAME" && (React.createElement(SelectInput, { items: options.street, onSelect: ({ value, label }) => {
                updateChoice({ street: value });
                updateForm({ street: label });
                setActiveStep("ENTER_HOUSE_NUMBER");
            } })),
        activeStep === "ENTER_HOUSE_NUMBER" && (React.createElement(TextInput, { placeholder: "House number", value: form.house ?? "", onChange: house => {
                updateForm({ house });
            }, onSubmit: async () => {
                if (form.house === undefined ||
                    choice.postalCode === undefined ||
                    choice.street === undefined) {
                    return;
                }
                setActiveStep("LOADING");
                updateForm({ house: form.house });
                const recypark = await api.getRecypark({
                    postalCode: form.postalCode.split(" ")[0],
                    street: form.street,
                    house: Number.parseInt(form.house, 10),
                });
                const calendar = await api.getCalendar({
                    postalCode: choice.postalCode,
                    street: choice.street,
                    house: Number.parseInt(form.house, 10),
                    address: `${form.street} ${form.house}, ${form.postalCode}`,
                });
                await toFile(calendar, recypark);
                setActiveStep("FINISH");
                exit();
            } })),
        activeStep === "FINISH" && (React.createElement(Box, { flexDirection: "column" },
            React.createElement(Text, null, "Done! \uD83D\uDE80"),
            React.createElement(Box, { marginBottom: 1 }),
            React.createElement(Text, null, "1. Create a dedicated calendar"),
            React.createElement(Text, null, "2. Import it:"),
            React.createElement(Text, null,
                "- GMail:",
                " ",
                React.createElement(Link, { url: "https://calendar.google.com/calendar/u/0/r/settings/export" }, "https://calendar.google.com/calendar/u/0/r/settings/export")),
            React.createElement(Text, null,
                "- ICloud:",
                " ",
                React.createElement(Link, { url: "https://support.apple.com/guide/calendar/import-or-export-calendars-icl1023/mac" }, "https://support.apple.com/guide/calendar/import-or-export-calendars-icl1023/mac")),
            React.createElement(Text, null,
                "- Outlook:",
                " ",
                React.createElement(Link, { url: "https://outlook.live.com/calendar/0/addcalendar" }, "https://outlook.live.com/calendar/0/addcalendar"))))));
}
