import axios from "axios";
import axiosRetry from "axios-retry";
axiosRetry(axios, {
    retries: 3,
    retryDelay() {
        return 1000;
    },
});
export const localize = async (address) => {
    const url = new URL("https://nominatim.openstreetmap.org/search");
    url.searchParams.append("addressdetails", "1");
    url.searchParams.append("q", address);
    url.searchParams.append("format", "json");
    const { data } = await axios.get(url.toString());
    if (data.length === 0 || !data[0]) {
        // cSpell:disable
        throw new Error("Address not found using Nominatim OpenStreetMap API.");
    }
    return {
        longitude: Math.floor(Number.parseFloat(data[0].lon) * 1000) / 1000,
        latitude: Math.floor(Number.parseFloat(data[0].lat) * 1000) / 1000,
    };
};
export const computeWeight = async (start, end) => {
    // prettier-ignore
    const url = new URL(`https://routing.openstreetmap.de/routed-car/route/v1/driving/${start.longitude},${start.latitude};${end.longitude},${end.latitude}`);
    url.searchParams.append("overview", "false");
    url.searchParams.append("alternatives", "false");
    url.searchParams.append("steps", "false");
    const { data } = await axios.get(url.toString(), {});
    if (!data?.routes) {
        // cSpell:disable
        throw new Error(`Unable to find a route using OpenStreetMap routing API using the given coordinates: ${start.longitude},${start.latitude};${end.longitude},${end.latitude}`);
    }
    const { duration, distance, weight } = data.routes[0];
    return duration + distance + weight;
};
